#!/usr/bin/env node 
const fs = require('fs'); 
const program = require('commander'); 
const download = require('download-git-repo'); 
const inquirer = require('inquirer'); 
const ora = require('ora'); 
const chalk = require('chalk'); 
const symbols = require('log-symbols'); 

const jsonReplace=function (str, obj) {
    var result=str;
    for(var k in obj){
        let reg=new RegExp('(\\"'+k+'\\"\\:\\s\\")([A-Za-z0-9\\+-_\\s]+)(\\")');
        result = result.replace(reg, function(match, p1, p2, p3) {
            return p1+obj[k]+p3
        })
    }
    return result;
}

program.version('1.0.0', '-v, --version') 
       .command('init <name>') 
       .action((name) => { 
            if(!fs.existsSync(name)){ 
                inquirer.prompt([ 
                    { 
                        name: 'description', 
                        message: '请输入项目描述' 
                    }, 
                    { 
                        name: 'author', 
                        message: '请输入作者名称' 
                    } 
                ]).then((answers) => { 
                    const spinner = ora('正在下载模板...'); 
                    spinner.start(); 
                    download('hsiangleev/vue-element-manager', name, {clone: true}, (err) => { 
                        if(err){ 
                            spinner.fail(); 
                            console.log(symbols.error, chalk.red(err)); 
                        }else{ 
                            spinner.succeed(); 
                            const fileName = `${name}/package.json`; 
                            const meta = { 
                                name, 
                                description: answers.description, 
                                author: answers.author 
                            } 
                            if(fs.existsSync(fileName)){ 
                                const content = fs.readFileSync(fileName).toString(); 
                                const result = jsonReplace(content, meta);
                                fs.writeFileSync(fileName, result); 
                            } 
                            console.log(symbols.success, chalk.green('项目初始化完成')); 
                            console.log(chalk.green('执行以下命令：')); 
                            console.log(chalk.green(`1. cd ${name}`)); 
                            console.log(chalk.green('2. npm install')); 
                            console.log(chalk.green('3. npm run serve')); 
                        } 
                    }) 
                }) 
            }else{ 
                // 错误提示项目已存在，避免覆盖原有项目 
                console.log(symbols.error, chalk.red('项目已存在')); 
            } 
       }); 
program.parse(process.argv);